==> honeycronpot-1.0.1.tar.gz: honeycronpot/src/Hook/HoneycronpotCron.php <==
<?php

namespace Drupal\honeycronpot\Hook;

use Drupal\Core\Config\ConfigFactoryInterface;
use Psr\Log\LoggerInterface;

/**
 * Handles honeycronpot cron tasks.
 */
class HoneycronpotCron {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The logger channel.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a HoneycronpotCron object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, LoggerInterface $logger) {
    $this->configFactory = $configFactory;
    $this->logger = $logger;
  }

  /**
   * Executes the cron tasks.
   */
  public function onCron() {
    $base_names = [
      'name', 'email', 'homepage', 'link', 'contact', 'user', 'address', 'phone', 'mobile', 'url', 'website',
      'location', 'firstname', 'lastname', 'company', 'organization', 'zipcode', 'city', 'street', 'username',
      'message', 'comment', 'feedback', 'text', 'info', 'description', 'title', 'subject', 'formfield', 'data',
    ];

    $prefixes = [
      'customer_', 'client_', 'account_', 'member_', 'contact_', 'profile_', 'person_', 'applicant_', 'registrant_',
      'participant_', 'subscriber_', 'lead_', 'visitor_', 'guest_', 'requester_', 'submitter_', 'respondent_',
      'enquirer_', 'follower_', 'donor_', 'supporter_', 'attendee_', 'memberinfo_', 'signup_', 'joiner_', 'volunteer_',
      'buyer_', 'userinput_', 'formuser_', 'interested_',
    ];

    $random_base = $base_names[array_rand($base_names)];
    $random_prefix = $prefixes[array_rand($prefixes)];
    $element_name = $random_prefix . $random_base;

    if (preg_match('/^[-_a-zA-Z0-9]+$/', $element_name)
      && preg_match('/^[a-zA-Z]/', $element_name)
      && !in_array($random_base, ['name', 'pass', 'website'])) {

      $this->configFactory->getEditable('honeypot.settings')
        ->set('element_name', $element_name)
        ->save();

      $this->logger->notice('Honeypot element_name via Cron updated: @name', ['@name' => $element_name]);
    }
    else {
      $this->logger->warning('Invalid element_name during Cron run: @name', ['@name' => $element_name]);
    }
  }

}

==> honeycronpot-1.0.2.tar.gz: honeycronpot/src/Hook/HoneycronpotCron.php <==
<?php

namespace Drupal\honeycronpot\Hook;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Psr\Log\LoggerInterface;

/**
 * Handles honeycronpot cron tasks.
 */
class HoneycronpotCron {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The logger channel.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a HoneycronpotCron object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, LoggerInterface $logger, EntityTypeManagerInterface $entityTypeManager) {
    $this->configFactory = $configFactory;
    $this->logger = $logger;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * Executes the cron tasks.
   */
  public function onCron() {
    $base_names = [
      'name', 'email', 'homepage', 'link', 'contact', 'user', 'address', 'phone', 'mobile', 'url', 'website',
      'location', 'firstname', 'lastname', 'company', 'organization', 'zipcode', 'city', 'street', 'username',
      'message', 'comment', 'feedback', 'text', 'info', 'description', 'title', 'subject', 'formfield', 'data',
    ];

    $prefixes = [
      'customer_', 'client_', 'account_', 'member_', 'contact_', 'profile_', 'person_', 'applicant_', 'registrant_',
      'participant_', 'subscriber_', 'lead_', 'visitor_', 'guest_', 'requester_', 'submitter_', 'respondent_',
      'enquirer_', 'follower_', 'donor_', 'supporter_', 'attendee_', 'memberinfo_', 'signup_', 'joiner_', 'volunteer_',
      'buyer_', 'userinput_', 'formuser_', 'interested_',
    ];

    $random_base = $base_names[array_rand($base_names)];
    $random_prefix = $prefixes[array_rand($prefixes)];
    $element_name = $random_prefix . $random_base;

    $existing_element_names = [];
    $webforms = $this->entityTypeManager->getStorage('webform')->loadMultiple();
    foreach ($webforms as $webform) {
      $elements = $webform->getElementsDecoded();
      $existing_element_names = array_merge($existing_element_names, array_keys($elements));
    }

    $existing_element_names = array_unique($existing_element_names);

    if (preg_match('/^[-_a-zA-Z0-9]+$/', $element_name)
      && preg_match('/^[a-zA-Z]/', $element_name)
      && !in_array($random_base, ['name', 'pass', 'website'])
      && !in_array($element_name, $existing_element_names)) {

      $this->configFactory->getEditable('honeypot.settings')
        ->set('element_name', $element_name)
        ->save();

      $this->logger->notice('Honeypot element_name via Cron updated: @name', ['@name' => $element_name]);
    }
    else {
      $this->logger->warning('Invalid element_name during Cron run: @name', ['@name' => $element_name]);
    }
  }

}
